# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-03 11:20
from __future__ import unicode_literals

from django.db import migrations

from os.path import dirname, join


def load_views():
    script_path = dirname(__file__)
    with open(join(script_path, '../support/views.sql')) as stmts:
        return stmts.read()


class Migration(migrations.Migration):

    dependencies = [
        ('maccman', '0001_initial'),
    ]

    operations = [
        migrations.RunSQL(load_views())
    ]
